pyprocar.io.vasp.Procar — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.io.vasp.Procar

class pyprocar.io.vasp.Procar(filename: str = 'PROCAR', structure: Structure | None = None, reciprocal_lattice: ndarray | None = None, kpath: KPath | None = None, n_kx: int | None = None, n_ky: int | None = None, n_kz: int | None = None, efermi: float | None = None, interpolation_factor: float = 1)

  A class to parse the PROCAR file

  Parameters:

    - filename (str, optional) – The PROCAR filename, by default “PROCAR”

    - structure (pyprocar.core.Structure, optional) – The structure of the calculation, by default None

    - reciprocal_lattice (np.ndarray, optional) – The reciprocal lattice matrix, by default None

    - kpath (pyprocar.core.KPath, optional) – The pyprocar.core.KPath object, by default None

    - kpoints (np.ndarray, optional) – The kpoints, by default None

    - efermi (float, optional) – The fermi energy, by default None

    - interpolation_factor (int, optional) – The interpolation factor, by default 1

  Methods

  `Procar.__init__`([filename, structure, ...]) |
  `Procar.repair`() | It Tries to repair some stupid problems due the stupid fixed format of the stupid fortran.
  `Procar.symmetrize`([symprec, outcar, ...]) | A method that will symmetrize the kpoints, projections, and bands of the calculation

  Attributes

  `Procar.kpoints_cartesian` | The kpoints in cartesian coordinates
  `Procar.kpoints_reduced` | The kpoints in reduced coordinates